# SMQTK - Core

## Intent
Provide a light-weight framework for developing interfaces that have built-in
implementation discovery and factory construction from configuration.

## Documentation
https://smqtk-core.readthedocs.io/en/stable/

You can also build the sphinx documentation locally for the most up-to-date
reference:
```bash
# Install dependencies
poetry install
# Navigate to the documentation root.
cd docs
# Build the docs.
poetry run make html
# Open in your favorite browser!
firefox _build/html/index.html
```
